%global major 1
%define libname %mklibname ispcrt %major
%define devname %mklibname -d ispcrt

%global with_snapshot	0
%global date		20190309
%global commit		34da2d23bbf32abf44da11d2cdca595dc7318cec
%global shortcommit	%(c=%{commit}; echo ${c:0:7})

%bcond_with examples

%define rel	1

Name:		ispc
Version:	1.18.1
%if %{with_snapshot}
Release:	%mkrel -c git%{date} %{rel}
%else
Release:	%mkrel %{rel}
%endif
Summary:	C-based SPMD programming language compiler
Group:		Development/C
License:	BSD
URL:		https://ispc.github.io/
%if %{with_snapshot}
Source0:	https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
%else
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
%endif
BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	clang-devel
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	git
BuildRequires:	gcc-c++
BuildRequires:	llvm-devel
BuildRequires:	rst2html
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)

# Upstream only supports these architectures
ExclusiveArch:	x86_64 %{arm64}

Patch7:		llvm15-support.patch

# patches from upstream (starting from 100)
# (see https://github.com/ispc/ispc)
Patch100:	0038-Added-CMake-flag-and-ISPC-definition-to-enable-disab.patch
Patch101:	https://github.com/ispc/ispc/commit/ec35a6f8e60ba77e59a6f2bfec27011e0ab34dda.patch
Patch102:	0040-Produce-position-independent-code-for-testing.patch

# patches from fedora (starting from 200)
# 
# https://fedoraproject.org/wiki/Changes/Stop-Shipping-Individual-Component-Libraries-In-clang-lib-Package
#
# rediffed after Patch100
Patch200:	0001-Link-against-libclang-cpp.so-rediff.patch

# other patches
# Fix examples path
Patch300:	ispc-1.11.0-examples-path.patch
#
# rediffed from https://github.com/ispc/ispc/commit/ac0b30f1dbc299553a8a723640fb97a0f559c195
Patch301:	0041-Support-LLVM-15-in-alloy.py-rediff.patch
# inspired from gentoo (completes patch200)
Patch302:	ispc-1.18.0-link-against-libclang-cpp-part-2.patch
# rediffed from https://github.com/ispc/ispc/commit/17328c5e704fa1fc7802114fed665d0d7779bb31
Patch303:	0152-Fixed-memory-leak-in-Array-constructor-rediff.patch

%if ! %{with examples}
Obsoletes:	%{name}-examples < 1.16.1-2
%endif

%description
A compiler for a variant of the C programming language, with extensions for
"single program, multiple data" (SPMD) programming.

%package examples
Summary:        Examples binaries for ispc
Group:          Development/C

%description examples
This package contains the examples binaries for the ispc SPMD compiler.

%package -n %libname
Summary: Library for ispc
Group: System/Libraries

%description -n %libname
Library for ispc.

%package -n %devname
Group:          Development/C
Summary:	Development files for %{name}
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
 applications that use %{name}.
 
%prep
%if %{with_snapshot}
%autosetup -n %{name}-%{commit} -p1
%else
%autosetup -n %{name}-%{version} -p1
%endif

# Use gcc rather clang by default
sed -i 's|set(CMAKE_C_COMPILER "clang")|set(CMAKE_C_COMPILER "gcc")|g' CMakeLists.txt
sed -i 's|set(CMAKE_CXX_COMPILER "clang++")|set(CMAKE_CXX_COMPILER "g++")|g' CMakeLists.txt

# Delete unrecognized command options from gcc-c++
sed -i 's|-Wno-c99-extensions -Wno-deprecated-register||g' CMakeLists.txt

# Suppress warning message as error
sed -i 's| -Werror ||g' CMakeLists.txt

# Fix all Python shebangs recursively in .
%py3_shebang_fix .

%build
%cmake	\
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DCMAKE_EXE_LINKER_FLAGS="%{build_ldflags} -fPIE" \
	-DISPC_INCLUDE_EXAMPLES=%{?with_examples:ON}%{!?with_examples:OFF} \
	-DISPC_INCLUDE_TESTS=OFF \
	-DISPC_NO_DUMPS=ON \
	-DLLVM_ENABLE_ASSERTIONS=OFF \
	-DLEVEL_ZERO_INCLUDE_DIR=%{_includedir} \
	-DLEVEL_ZERO_LIB_LOADER=%{_libddir}
%cmake_build

(
 cd ./docs/
 ./build.sh
)

%install
%cmake_install

#Remove static file
rm %{buildroot}%{_libdir}/lib%{name}rt_static.a

%files
%license LICENSE.txt
%doc docs/*.html docs/ReleaseNotes.txt
%{_bindir}/%{name}
%{_bindir}/check_isa

%if %{with examples}
%files examples
#{_prefix}/lib/ispc/examples
%endif

%files -n %libname
%{_libdir}/lib%{name}rt.so.%{major}{,.*}

%files -n %devname
%{_includedir}/%{name}rt/
%{_libdir}/cmake/%{name}rt-%{version}/
%{_libdir}/lib%{name}rt.so


%changelog
* Fri Nov 11 2022 ghibo <ghibo> 1.18.1-1.mga9
+ Revision: 1905523
- Update to release 1.18.1.
- Backport more patches from upstream 1.19.0-dev to fix crashes during oidn package building.
- Reorder patchsets.

* Sun Sep 25 2022 tv <tv> 1.18.0-2.mga9
+ Revision: 1892275
- Add support for llvm-15
- Rebuild for llvm-15

* Sun May 08 2022 tv <tv> 1.18.0-1.mga9
+ Revision: 1856758
- Update to 1.18.0

* Sat Apr 02 2022 tv <tv> 1.17.0-2.mga9
+ Revision: 1840359
- Rebuild for llvm-14

* Sun Mar 13 2022 ghibo <ghibo> 1.17.0-1.mga9
+ Revision: 1790827
- Update to release 1.17.0
- Drop Patch1 (merged upstream)

* Sat Dec 25 2021 wally <wally> 1.16.1-2.mga9
+ Revision: 1763620
- drop empty examples pkg

* Sat Dec 25 2021 wally <wally> 1.16.1-1.mga9
+ Revision: 1763615
- disable examples build
- enable aarch64 build
- add patch to fix build with llvm 13
- use proper linker flags
+ tv <tv>
- 1.16.1
- Rebuild for llvm 13.0

* Mon Jun 14 2021 tv <tv> 1.16.0-1.mga9
+ Revision: 1730741
- "Fix" file list
- Update to 1.16.0

* Wed May 19 2021 tv <tv> 1.15.0-1.mga9
+ Revision: 1725561
- Update to 1.15.0
- rebuild for llvm/clang-12

* Thu Nov 26 2020 tv <tv> 1.14.1-2.mga8
+ Revision: 1649613
- rebuild for llvm/clang 11.0

* Sun Sep 13 2020 ghibo <ghibo> 1.14.1-1.mga8
+ Revision: 1625446
- Disable aarch64 building.
- Re-enable arm components.
- Disable ARM components
- Update to release 1.14.1.
- Drop patches merged upstream.
- Fix cmake_build arguments
- Update to release 1.14.0
+ tv <tv>
- kill old patches
- try to fix build

* Mon Jun 01 2020 ghibo <ghibo> 1.13.0-3.mga8
+ Revision: 1589347
- Cleaned SPEC file

* Mon Jun 01 2020 ghibo <ghibo> 1.13.0-2.mga8
+ Revision: 1589329
- Bump rel
- Exclusive arch x86_64 only
- Temporary disable i586 arch
- Fix clang-cpp patch
- Add patches from git to fix i586 building
- Switch from autosetup to setup for finetuning the patchset
- Rework clang-cpp patch.
- Add a BR
- Update to release 1.13.0
- Added two patch to override compiling errors
+ tv <tv>
- rebuild with llvm 10
+ wally <wally>
- build with new cmake macros

* Tue Sep 17 2019 tv <tv> 1.12.0-1.mga8
+ Revision: 1443128
- Update to 1.12.0
- Switch dependency to Python 3
- rebuild for llvm-9.0

* Sun May 26 2019 ghibo <ghibo> 1.11.0-3.mga7
+ Revision: 1399198
- Exclude arm building for now

* Sun May 26 2019 ghibo <ghibo> 1.11.0-2.mga7
+ Revision: 1399186
- Add patches from git for arm building.

* Sun May 26 2019 ghibo <ghibo> 1.11.0-1.mga7
+ Revision: 1399138
- imported package ispc


* Sat May 25 2019 ghibo <ghibo> - 1.11.0-1.mga7
- Initial release based on FC.
- Add docs
